@@ -7,17 +7,20 @@ class Worker:
     db_config: DbConfig
     logger: DefaultLogger
 
-    @classmethod
-    def use_db_connection(cls, func):
+    def __init__(self, db_config:DbConfig, logger: DefaultLogger) -> None:
+        self.db_config = db_config
+        self.logger  = logger
+
+    def use_db_connection(self, func):
         '''Decorator that reports the execution time.'''
 
         async def wrap(*args, **kwargs):
-            await cls.db_config.connect_db(NullPool)
+            await self.db_config.connect_db(NullPool)
             result = None
             try:
                 result = await func(*args, **kwargs)
             except Exception as ex:
-                cls.logger.error(ex)
-            await cls.db_config.disconnect_db()
+                self.logger.error(ex)
+            await self.db_config.disconnect_db()
             return result
         return wrap
